pub struct Bbr3Config { /* private fields */ }Expand description
Configuration for the Bbr3 congestion controller
Different pacing_gains can be set to modify the multiplier used to
increase the sending rates.
Different cwnd_gains can be set to modify the multiplier used to increase
the congestion windows.
All of these parameters are specific to different states of the algorithm: see BbrState
pacing_margin_percent is used to set a margin when calculating the pacing_rate in order
to not send at 100% capacity when calculating pacing.
Implementations
Sourceimpl Bbr3Config
impl Bbr3Config
Sourcepub fn initial_window(&mut self, value: u64) -> &mut Self
pub fn initial_window(&mut self, value: u64) -> &mut Self
Default limit on the amount of outstanding data in bytes.
Recommended value: min(10 * max_datagram_size, max(2 * max_datagram_size, 14720))