#[non_exhaustive]pub struct HandshakeData {
pub protocol: Option<Vec<u8>>,
pub server_name: Option<String>,
pub negotiated_key_exchange_group: Option<NamedGroup>,
}Expand description
Authentication data for (rustls) TLS session
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.protocol: Option<Vec<u8>>The negotiated application protocol, if ALPN is in use
Guaranteed to be set if a nonempty list of protocols was specified for this connection.
server_name: Option<String>The server name specified by the client, if any
Always None for outgoing connections
negotiated_key_exchange_group: Option<NamedGroup>The key exchange group negotiated with the peer. Useful for logging and metrics.
None until the handshake has completed.