PathAbandonReason

Enum PathAbandonReason 

pub enum PathAbandonReason {
    ApplicationClosed {
        error_code: VarInt,
    },
    ValidationFailed,
    TimedOut,
    UnusableAfterNetworkChange,
    NatTraversalRoundEnded,
    RemoteAbandoned {
        error_code: VarInt,
    },
}
Reason for why a path was abandoned.

Variants



ApplicationClosed

The path was closed locally by the application.

Fields

error_code: VarInt

The error code to be sent with the abandon frame.



ValidationFailed

We didn’t receive a path response in time after opening this path.



TimedOut

We didn’t receive any data from the remote within the path’s idle timeout.



UnusableAfterNetworkChange

The path became unusable after a local network change.



NatTraversalRoundEnded

The path was opened in a NAT traversal round which was terminated.



RemoteAbandoned

The remote closed the path.

Fields

error_code: VarInt

The error that was sent with the abandon frame.