PathEvent

Enum PathEvent 

pub enum PathEvent {
    Opened {
        id: PathId,
    },
    Abandoned {
        id: PathId,
        reason: PathAbandonReason,
    },
    Discarded {
        id: PathId,
        path_stats: PathStats,
    },
    RemoteStatus {
        id: PathId,
        status: PathStatus,
    },
    ObservedAddr {
        id: PathId,
        addr: SocketAddr,
    },
}
Application events about paths

Variants



Opened

A new path has been opened

Fields

id: PathId

Which path is now open



Abandoned

A path was abandoned and is no longer usable.

This event will always be followed by Self::Discarded after some time.

Fields

id: PathId

With path was abandoned.

reason: PathAbandonReason

Reason why this path was abandoned.



Discarded

A path was discarded and all remaining state for it has been removed.

This event is the last event for a path, and is always emitted after Self::Abandoned.

Fields

id: PathId

Which path had its state dropped

path_stats: PathStats

The final path stats, they are no longer available via Connection::stats



RemoteStatus

The remote changed the status of the path

The local status is not changed because of this event. It is up to the application to update the local status, which is used for packet scheduling, when the remote changes the status.

Fields

id: PathId

Path which has changed status

status: PathStatus

The new status set by the remote



ObservedAddr

Received an observation of our external address from the peer.

Fields

id: PathId

Path over which the observed address was reported, PathId::ZERO when multipath is not negotiated

addr: SocketAddr

The address observed by the remote over this path