#[non_exhaustive]pub struct ConnectionStats {
pub udp_tx: UdpStats,
pub udp_rx: UdpStats,
pub frame_tx: FrameStats,
pub frame_rx: FrameStats,
pub lost_packets: u64,
pub lost_bytes: u64,
}Expand description
Connection statistics.
The fields here are a sum of the respective fields in the PathStats for all the
paths that exist as well as all paths that previously existed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.udp_tx: UdpStatsStatistics about UDP datagrams transmitted on the connection.
udp_rx: UdpStatsStatistics about UDP datagrams received on the connection.
frame_tx: FrameStatsStatistics about frames transmitted on the connection.
frame_rx: FrameStatsStatistics about frames received on the connection.
lost_packets: u64The number of packets lost on the connection.
lost_bytes: u64The number of bytes lost on the connection.