PathStats

Struct PathStats 

#[non_exhaustive]
pub struct PathStats {
Show 14 fields pub rtt: Duration, pub udp_tx: UdpStats, pub udp_rx: UdpStats, pub frame_tx: FrameStats, pub frame_rx: FrameStats, pub cwnd: u64, pub congestion_events: u64, pub spurious_congestion_events: u64, pub lost_packets: u64, pub lost_bytes: u64, pub sent_plpmtud_probes: u64, pub lost_plpmtud_probes: u64, pub black_holes_detected: u64, pub current_mtu: u16,
}
Statistics related to a transmission path.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
rtt: Duration

Current best estimate of this connection’s latency (round-trip-time).

udp_tx: UdpStats

Statistics about datagrams and bytes sent on this path.

udp_rx: UdpStats

Statistics about datagrams and bytes received on this path.

frame_tx: FrameStats

Statistics about frames transmitted on this path.

frame_rx: FrameStats

Statistics about frames received on this path.

cwnd: u64

Current congestion window of the connection.

congestion_events: u64

Congestion events on the connection.

spurious_congestion_events: u64

Spurious congestion events on the connection.

lost_packets: u64

The number of packets lost on this path.

lost_bytes: u64

The number of bytes lost on this path.

sent_plpmtud_probes: u64

The number of PLPMTUD probe packets sent on this path.

These are also counted by UdpStats::datagrams.

lost_plpmtud_probes: u64

The number of PLPMTUD probe packets lost on this path.

These are not included in Self::lost_packets and Self::lost_bytes.

black_holes_detected: u64

The number of times a black hole was detected in the path.

current_mtu: u16

Largest UDP payload size the path currently supports.