#[non_exhaustive]pub struct PathStats {Show 14 fields
pub rtt: Duration,
pub udp_tx: UdpStats,
pub udp_rx: UdpStats,
pub frame_tx: FrameStats,
pub frame_rx: FrameStats,
pub cwnd: u64,
pub congestion_events: u64,
pub spurious_congestion_events: u64,
pub lost_packets: u64,
pub lost_bytes: u64,
pub sent_plpmtud_probes: u64,
pub lost_plpmtud_probes: u64,
pub black_holes_detected: u64,
pub current_mtu: u16,
}Expand description
Statistics related to a transmission path.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rtt: DurationCurrent best estimate of this connection’s latency (round-trip-time).
udp_tx: UdpStatsStatistics about datagrams and bytes sent on this path.
udp_rx: UdpStatsStatistics about datagrams and bytes received on this path.
frame_tx: FrameStatsStatistics about frames transmitted on this path.
frame_rx: FrameStatsStatistics about frames received on this path.
cwnd: u64Current congestion window of the connection.
congestion_events: u64Congestion events on the connection.
spurious_congestion_events: u64Spurious congestion events on the connection.
lost_packets: u64The number of packets lost on this path.
lost_bytes: u64The number of bytes lost on this path.
sent_plpmtud_probes: u64The number of PLPMTUD probe packets sent on this path.
These are also counted by UdpStats::datagrams.
lost_plpmtud_probes: u64The number of PLPMTUD probe packets lost on this path.
These are not included in Self::lost_packets and Self::lost_bytes.
black_holes_detected: u64The number of times a black hole was detected in the path.
current_mtu: u16Largest UDP payload size the path currently supports.